@@ -1,9 +1,9 @@
-'''
+"""
 @说明    :动态用户组刷新
 @时间    :2019/12/25 下午12:12:24
 @作者    :任秋锴
 @版本    :1.0
-'''
+"""
 
 import requests
 
@@ -30,13 +30,11 @@ class cjdgUserGroup:
 
     def get(self, group_id):
         url = "http://bms.chaojidaogou.com/shopguide/groupfindGroupDynamicAttr.jhtml"
-        data = {
-            "usergroup.groupId": group_id
-        }
+        data = {"usergroup.groupId": group_id}
         response = requests.post(url, data=data, headers=self.headers)
         if response.status_code == 200:
             result = response.json()
-            return (result)
+            return result
 
     def saveFlush(self, group_id):
         data = self.get(group_id)
@@ -63,8 +61,7 @@ class cjdgUserGroup:
         response = requests.post(url, data=data, headers=self.headers)
         if response.status_code == 200:
             result = response.json()
-            return (result)
-
+            return result
 
 
 def testcase1():
@@ -74,6 +71,7 @@ def testcase1():
     print(ug.saveFlush(group_id))
     # print(userGroupFlush(group_id, token))
 
+
 if __name__ == "__main__":
     testcase1()
     # print(userGroupFlush(group_id, token))
